@@ -8,11 +8,15 @@ from signum.plotting.plotter import Plotter
 
 
 class BodePlotter(Plotter):
-    def __init__(self, figsize=(8, 6), db_scale: bool = False, rad: bool = False, unwrapped: bool = False, **kwargs):
+    def __init__(self, figsize=(8, 6), db_scale: bool = False, rad: bool = False, unwrapped: bool = False,
+                 unit='', x_unit='', **kwargs):
         super().__init__(n_rows=2, n_cols=1, sharex='all', figsize=figsize, **kwargs)
 
-        self.amplitude_ax.set_ylabel(f"Amplitude{' [db]' if db_scale else ''}")
-        self.phase_ax.set_ylabel(f"Phase [{'rad' if rad else 'deg'}]")
+        self.amplitude_ax.set_ylabel(f"Amplitude")
+        self.amplitude_ax.set_y_unit('dB' if db_scale else unit)
+        self.phase_ax.set_ylabel(f"Phase")
+        self.phase_ax.set_y_unit('rad' if rad else 'deg')
+        self.phase_ax.set_x_unit(x_unit)
 
         self._db_scale = db_scale
         self._rad = rad
@@ -28,14 +32,10 @@ class BodePlotter(Plotter):
 
     def _add_line(self, signal: 'SignalContainer', **kwargs):
         mag = signal.magnitude_db if self._db_scale else signal.magnitude
-        amplitude_line, = self.amplitude_ax.plot(signal.x_axis, mag.T, **kwargs)
+        amplitude_lines = self.amplitude_ax.plot(mag.T, **kwargs)
 
         phase = signal.get_phase(rad=self._rad, unwrapped=self._unwrapped)
-        phase_line, = self.phase_ax.plot(signal.x_axis, phase.T, **kwargs)
+        phase_lines = self.phase_ax.plot(phase.T, **kwargs)
 
-        return amplitude_line, phase_line
-
-    def _update_labels(self):
-        self.amplitude_ax.set_ylabel(f"Amplitude {'[db]' if self._db_scale else self.unit_bracket}")
-        self.phase_ax.set_xlabel(f"{self.x_description} {self.x_unit_bracket}")
+        return amplitude_lines, phase_lines
 
