@@ -8,12 +8,16 @@ from signum.plotting.plotter import Plotter
 
 
 class IQPlotter(Plotter):
-    def __init__(self, figsize=(8, 6), sharey='all', **kwargs):
+    def __init__(self, figsize=(8, 6), sharey='all', unit='', x_unit='', **kwargs):
         super().__init__(n_rows=2, n_cols=1, sharex='all', sharey=sharey, figsize=figsize, **kwargs)
 
         self.i_ax.set_ylabel("Real")
         self.q_ax.set_ylabel("Imag")
 
+        self.i_ax.set_y_unit(unit)
+        self.q_ax.set_y_unit(unit)
+        self.q_ax.set_x_unit(x_unit)
+
     @property
     def i_ax(self) -> plt.Axes:
         return self.axes[0, 0]
@@ -23,13 +27,8 @@ class IQPlotter(Plotter):
         return self.axes[1, 0]
 
     def _add_line(self, signal: 'SignalContainer', **kwargs):
-        i_line, = self.i_ax.plot(signal.x_axis, signal.real.T, **kwargs)
-        q_line, = self.q_ax.plot(signal.x_axis, signal.imag.T, **kwargs)
+        i_lines = self.i_ax.plot(signal.real.T, **kwargs)
+        q_lines = self.q_ax.plot(signal.imag.T, **kwargs)
 
-        return i_line, q_line
-
-    def _update_labels(self):
-        self.i_ax.set_ylabel(f"Real {self.unit_bracket}")
-        self.q_ax.set_ylabel(f"Imag {self.unit_bracket}")
-        self.q_ax.set_xlabel(f"{self.x_description} {self.x_unit_bracket}")
+        return i_lines, q_lines
 
